==> veyon_4.4.1+repack1.orig.tar.xz: veyon-4.4.1/master/src/FlexibleListView.h <==
/*
 * FlexibleListView.h - list view with flexible icon positions
 *
 * Copyright (c) 2018-2020 Tobias Junghans <tobydox@veyon.io>
 *
 * This file is part of Veyon - https://veyon.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#pragma once

#include <QListView>

class FlexibleListView : public QListView
{
	Q_OBJECT
public:
	explicit FlexibleListView( QWidget *parent = nullptr );
	~FlexibleListView() override = default;

	void setUidRole( int role );

	void setFlexible( bool enabled );
	bool flexible() const;

	void alignToGrid();

	QJsonArray savePositions();
	void loadPositions( const QJsonArray& data );

public:
	void doItemsLayout() override;

private:
	void restorePositions();
	void updatePositions();

private:
	QSizeF effectiveGridSize() const;
	QPointF toGridPoint( QPoint pos ) const;
	QPoint toItemPosition( QPointF gridPoint ) const;

	int m_uidRole;
	QHash<QUuid, QPointF> m_positions;

};

==> veyon_4.5.2+repack1.orig.tar.xz: veyon-4.5.2/master/src/FlexibleListView.h <==
/*
 * FlexibleListView.h - list view with flexible icon positions
 *
 * Copyright (c) 2018-2020 Tobias Junghans <tobydox@veyon.io>
 *
 * This file is part of Veyon - https://veyon.io
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program (see COPYING); if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#pragma once

#include <QListView>

class FlexibleListView : public QListView
{
	Q_OBJECT
public:
	explicit FlexibleListView( QWidget *parent = nullptr );
	~FlexibleListView() override = default;

	void setUidRole( int role );

	void setFlexible( bool enabled );
	bool flexible() const;

	void alignToGrid();

	QJsonArray savePositions();
	void loadPositions( const QJsonArray& data );

public:
	void doItemsLayout() override;

protected:
	bool viewportEvent( QEvent* event ) override;
	void dataChanged( const QModelIndex& topLeft, const QModelIndex& bottomRight,
					  const QVector<int>& roles ) override;

private:
	void restorePositions();
	void updatePositions();

	QSizeF effectiveGridSize() const;
	QPointF toGridPoint( QPoint pos ) const;
	QPoint toItemPosition( QPointF gridPoint ) const;

	int m_uidRole;
	QHash<QUuid, QPointF> m_positions;

	QPoint m_toolTipPos;
};
